@@ -25,7 +25,7 @@ class DltkAiClient:
                 DltkAiClient: Client object for DltkAi.
         """
         self.api_key = api_key
-        self.base_url = "https://prod-kong.dltk.ai"
+        self.base_url = "https://dev-kong.dltk.ai"
 
     def sentiment_analysis(self, text):
         """
@@ -42,6 +42,21 @@ class DltkAiClient:
         print(response.text)
         return response
 
+    def sentiment_analysis_compare(self, text, sources):
+        """
+        :param str text: The text on which sentiment analysis is to be applied.
+        :return:
+            obj:A json obj containing sentiment analysis response.
+        """
+
+        body = {'text': text,'sources':sources}
+        body = json.dumps(body)
+        url =self.base_url + '/core/nlp/sentiment/compare'
+        headers = {'ApiKey': self.api_key, 'Content-type': 'application/json'}
+        response = requests.post(url=url, data=body, headers=headers)
+        print(response.text)
+        return response
+
     def pos_tagger(self, text):
         """
         :param str text: The text on which POS analysis is to be applied.
@@ -56,6 +71,21 @@ class DltkAiClient:
         response = requests.post(url=url, data=body, headers=headers).json()
         return response
 
+    def pos_tagger_compare(self, text, sources):
+        """
+        :param str text: The text on which sentiment analysis is to be applied.
+        :return:
+            obj:A json obj containing sentiment analysis response.
+        """
+
+        body = {'text': text,'sources':sources}
+        body = json.dumps(body)
+        url = self.base_url + '/core/nlp/pos/compare'
+        headers = {'ApiKey': self.api_key, 'Content-type': 'application/json'}
+        response = requests.post(url=url, data=body, headers=headers)
+        print(response.text)
+        return response
+
     def ner_tagger(self, text):
         """
         :param str text: The text on which NER Tagger is to be applied.
@@ -70,6 +100,21 @@ class DltkAiClient:
         response = requests.post(url=url, data=body, headers=headers).json()
         return response
 
+    def ner_tagger_compare(self, text, sources):
+        """
+        :param str text: The text on which sentiment analysis is to be applied.
+        :return:
+            obj:A json obj containing sentiment analysis response.
+        """
+
+        body = {'text': text,'sources':sources}
+        body = json.dumps(body)
+        url = self.base_url + '/core/nlp/ner/compare'
+        headers = {'ApiKey': self.api_key, 'Content-type': 'application/json'}
+        response = requests.post(url=url, data=body, headers=headers)
+        print(response.text)
+        return response
+
     def dependency_parser(self, text):
         """
         :param str text: The text on which Dependency Parser is to be applied.
@@ -98,6 +143,21 @@ class DltkAiClient:
         response = requests.post(url=url, data=body, headers=headers).json()
         return response
 
+    def tags_compare(self, text, sources):
+        """
+        :param str text: The text on which sentiment analysis is to be applied.
+        :return:
+            obj:A json obj containing sentiment analysis response.
+        """
+
+        body = {'text': text,'sources':sources}
+        body = json.dumps(body)
+        url = self.base_url + '/core/nlp/tags/compare'
+        headers = {'ApiKey': self.api_key, 'Content-type': 'application/json'}
+        response = requests.post(url=url, data=body, headers=headers)
+        print(response.text)
+        return response
+
     # phoenix-vision
 
     def face_detection_image(self, image_path):
@@ -150,6 +210,19 @@ class DltkAiClient:
         response = requests.post(url=url, files=body, headers=headers).json()
         return response
 
+    def face_detection_compare(self, image_path,sources):
+        """
+        :param str image_path: The path of the image file.
+        :return
+            obj : A list of co-ordinates for all objects detected in the image.
+        """
+        body = {'image': (image_path, open(image_path, 'rb'), 'multipart/form-data')}
+        payload = {'sources':sources}
+        url = 'https://dev-kong.dltk.ai/core/vision/face-detection/compare'
+        headers = {'ApiKey': self.api_key}
+        response = requests.post(url=url, files=body, headers=headers,data=payload)
+        return response
+
     def eye_detection_image(self, image_path):
         """
         :param str image_path: The path of the image file.
@@ -250,6 +323,19 @@ class DltkAiClient:
         response = requests.post(url=url, files=body, headers=headers).json()
         return response
 
+    def object_detection_compare(self, image_path,sources):
+        """
+        :param str image_path: The path of the image file.
+        :return
+            obj : A list of co-ordinates for all objects detected in the image.
+        """
+        body = {'image': (image_path, open(image_path, 'rb'), 'multipart/form-data')}
+        payload = {'sources':sources}
+        url = 'https://dev-kong.dltk.ai/core/vision/object-detection/image/compare'
+        headers = {'ApiKey': self.api_key}
+        response = requests.post(url=url, files=body, headers=headers,data=payload)
+        return response
+
     def image_classification(self, image_path):
         """
         :param str image_path: The path of the image file.
@@ -262,6 +348,19 @@ class DltkAiClient:
         response = requests.post(url=url, files=body, headers=headers).json()
         return response
 
+    def image_classification_compare(self, image_path,sources):
+        """
+        :param str image_path: The path of the image file.
+        :return
+            obj : A list of co-ordinates for all objects detected in the image.
+        """
+        body = {'image': (image_path, open(image_path, 'rb'), 'multipart/form-data')}
+        payload = {'sources':sources}
+        url = 'https://dev-kong.dltk.ai/core/vision/image-classification/compare'
+        headers = {'ApiKey': self.api_key}
+        response = requests.post(url=url, files=body, headers=headers,data=payload)
+        return response
+
     def custom_image_clf_train(self, name, zip_folder_url, images_column, labels_column, train_percentage, epochs, steps_per_epoch):
         """
         :param str name: name of the service.
